/////////////////////////////////////////////////////////////////////////////
// Project:     wxIView
// Purpose:     Complex wxWidgets sample
// Name:        wxiviewcanvas.cpp
// Author:      Daniel Nell
// Created:     2005/10/18
// Copyright:   (c) Daniel Nell
// Licence:     wxWindows license
// Modified by:
/////////////////////////////////////////////////////////////////////////////

// For compilers that support precompilation, includes "wx/wx.h".
#include <wx/wxprec.h>
#ifndef WX_PRECOMP
   #include <wx/wx.h>
#endif

// Include additional wxWidgets headers.
#include <wx/image.h>
#include <wx/timer.h>

// Include private wxIView headers.
#include "wxiviewcanvas.h"


//////////////////////////////////////////////////////////
// The canvas window
//
DEFINE_EVENT_TYPE( wxEVT_IVIEWCANVASSIZE )

IMPLEMENT_DYNAMIC_CLASS( wxIViewCanvas, wxScrolledWindow )

BEGIN_EVENT_TABLE( wxIViewCanvas, wxScrolledWindow )
    EVT_PAINT(           wxIViewCanvas::OnPaint )
    EVT_SIZE(            wxIViewCanvas::OnSize  )
    EVT_TIMER( wxID_ANY, wxIViewCanvas::OnTimer )
END_EVENT_TABLE()


wxIViewCanvas::wxIViewCanvas( wxWindow *opParent, wxWindowID nId,
                              const wxPoint &oPos, const wxSize &oSize,
                              long nStyle, const wxString& strName )
  : wxScrolledWindow( opParent, nId, oPos, oSize, nStyle, strName )
{
    // Initialization.
    m_oTimer.SetOwner( this );
//SetCursor( wxCROSS_CURSOR );
}

wxIViewCanvas::~wxIViewCanvas()
{
    // Clean up.
    // [Nothing to do, yet.]
}

void wxIViewCanvas::OnPaint( wxPaintEvent &oEvent )
{
    // Create a device context...
    //
    wxPaintDC oDc( this );

    // ... and prepare it even if there is not a bitmap to paint
    // for to repaint at least the window background etc.
    //
    PrepareDC( oDc );

    // Paint (the bitmap).
    Paint( oDc );
}

bool wxIViewCanvas::Paint( wxDC& oDc )
{
    // If there is a bitmap connected to this canvas window (re)paint it.
    if( oDc.Ok() && m_oBitmap.Ok() )
    {
        // Repaint the bitmap.
        oDc.DrawBitmap( m_oBitmap, 0, 0 );

        // Signal success.
        return true;
    }
    else
    {
        // Signal failure.
        return false;
    }
}

void wxIViewCanvas::SetBitmap( const wxBitmap &oBitmap )
{
    // Save the (new) bitmap,...
    m_oBitmap= oBitmap;

    // ... adjust the scrollbars, ...
    SetScrollbars( 1, 1, m_oBitmap.GetWidth(), m_oBitmap.GetHeight() );

    // .. and refresh (repaint) the windown content.
    Refresh();
}

void wxIViewCanvas::OnSize( wxSizeEvent & WXUNUSED( oEvent ) )
{
	// Check if the timer is running, and...
    if( m_oTimer.IsRunning() )
    {
        // ... stop it.
        m_oTimer.Stop();
    }

	// Create a one shot timer event in 50ms.
    m_oTimer.Start( 50, wxTIMER_ONE_SHOT );
}

void wxIViewCanvas::OnTimer( wxTimerEvent & WXUNUSED( oEvent ) )
{
    // Notify the next window in the parent chain that the canvas size
    // has changed.
    //
    // Note: An event of type wxIViewCanvasSizeEvent is propageted
    //       to the parent window chain by default.
    wxIViewCanvasSizeEvent oEvent;

    ProcessEvent( oEvent );
}
