/////////////////////////////////////////////////////////////////////////////
// Project:     wxIView
// Purpose:     Complex wxWidgets sample
// Name:        wxIViewPrintout.h
// Author:      Daniel Nell
// Created:     2005/10/18
// Copyright:   (c) Daniel Nell
// License:     wxWindows license
// Modified by:
/////////////////////////////////////////////////////////////////////////////

#ifndef __WXIVIEWPRINTOUT_H
#define __WXIVIEWPRINTOUT_H

#define wxivIMAGEPPIX (180)
#define wxivIMAGEPPIY (180)


// Forward declartion.
class wxIViewPaintBase;


/////////////////////////////////////////////////////////////////////////////
//  class wxIViewPrintout
//
/// \brief ...
///
/// ...
class wxIViewPrintout : public wxPrintout
{
  public:
    /// \brief Standard constructor
    ///
    /// \param poPaint    a pointer to ...
    /// \param strTitle   ...
    wxIViewPrintout( wxIViewPaintBase *poPaint,
                     const wxString& strTitle= wxT( "wxIViewPrintout" ),
                     bool bFitToPage= true,
                     int nResolutionX= wxivIMAGEPPIX,
                     int nResolutionY= wxivIMAGEPPIY );

    /// ...
    virtual void GetPageInfo( int *nMinPage, int *nMaxPage, int *nSelPageFrom, int *nSelPageTo );

    /// ...
    virtual bool HasPage( int nPage );

    /// ...
    virtual bool OnPrintPage( int nPage );

  protected:
    wxIViewPaintBase *m_poPaint;    ///< Pointer to the parent object.
    bool m_bFitToPage;              ///< Flag: Should the output scaled to fix the printer page.
    int m_nResolutionX;             ///< Resolution in width direction in DPI.
    int m_nResolutionY;             ///< Resolution in height direction in DPI.
};


/////////////////////////////////////////////////////////////////////////////
//  class wxIViewPrintout
//
/// \brief ...
///
/// ...
class wxIViewPreviewFrame : public wxPreviewFrame
{
  public:
    /// \brief Standard constructor
    ///
    /// \param opPrintPreview    a pointer to ...
    /// \param poParentWindow    a pointer to the parent window
    /// \param strTitle          a string containing the window title
    /// \param oPos              window position, defaults to wxDefaultPosition
    /// \param oSize             window size, defaults to wxDefaultSize
    /// \param nStyle            window style, defaults to wxDEFAULT_FRAME_STYLE
    /// \param strName           a string containing class information
    wxIViewPreviewFrame( wxPrintPreview* opPrintPreview,
                         wxWindow* poParentWindow,
                         const wxString& strTitle= wxT( "Print Preview" ),
                         const wxPoint& oPos= wxDefaultPosition,
                         const wxSize& oSize= wxDefaultSize,
                         long  nStyle= wxDEFAULT_FRAME_STYLE,
                         const wxString& strName = wxT( "frame" ) )
      : wxPreviewFrame( opPrintPreview, poParentWindow, strTitle, oPos, oSize, nStyle,
                        strName )
    {
    }

    /// \brief Create the preview window's control bar.
    ///
    /// Creates a control bar that does not contain buttons for turning pages
    /// forward and backward if there is only one page that can be printed.
    /// The code is inspired on the default implementation of
    // wxPreviewFrame::CreateControlBar() in ${WXWIN}/src/common.prntbase.cpp .
    virtual void CreateControlBar();
};

#endif // __WXIVIEWPRINTOUT_H

